@@ -910,7 +910,6 @@ parse_link (EggDesktopFile  *desktop_file,
 	return TRUE;
 }
 
-#if GTK_CHECK_VERSION (2, 12, 0)
 static char *
 start_startup_notification (GdkDisplay     *display,
                             EggDesktopFile *desktop_file,
@@ -1022,7 +1021,6 @@ set_startup_notification_timeout (GdkDisplay *display,
 	g_timeout_add_seconds (EGG_DESKTOP_FILE_SN_TIMEOUT_LENGTH,
 	                       startup_notification_timeout, sn_data);
 }
-#endif /* GTK 2.12 */
 
 static GPtrArray *
 array_putenv (GPtrArray *env, char *variable)
@@ -1209,7 +1207,6 @@ egg_desktop_file_launchv (EggDesktopFile *desktop_file,
 		}
 		g_free (command);
 
-#if GTK_CHECK_VERSION (2, 12, 0)
 		startup_id = start_startup_notification (display, desktop_file,
 		             argv[0], screen_num,
 		             workspace, launch_time);
@@ -1220,9 +1217,6 @@ egg_desktop_file_launchv (EggDesktopFile *desktop_file,
 			env = array_putenv (env, startup_id_env);
 			g_free (startup_id_env);
 		}
-#else
-		startup_id = NULL;
-#endif /* GTK 2.12 */
 
 		if (env != NULL)
 			g_ptr_array_add (env, NULL);
@@ -1240,7 +1234,6 @@ egg_desktop_file_launchv (EggDesktopFile *desktop_file,
 
 		if (startup_id)
 		{
-#if GTK_CHECK_VERSION (2, 12, 0)
 			if (current_success)
 			{
 				set_startup_notification_timeout (display, startup_id);
@@ -1251,7 +1244,6 @@ egg_desktop_file_launchv (EggDesktopFile *desktop_file,
 					g_free (startup_id);
 			}
 			else
-#endif /* GTK 2.12 */
 				g_free (startup_id);
 		}
 		else if (ret_startup_id)
