@@ -36,6 +36,9 @@
 #include <X11/SM/SMlib.h>
 
 #include <gdk/gdk.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gdk/gdkx.h>
+#endif
 
 #define EGG_TYPE_SM_CLIENT_XSMP            (egg_sm_client_xsmp_get_type ())
 #define EGG_SM_CLIENT_XSMP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EGG_TYPE_SM_CLIENT_XSMP, EggSMClientXSMP))
@@ -374,7 +377,11 @@ sm_client_xsmp_startup (EggSMClient *client,
 		free (ret_client_id);
 
 		gdk_threads_enter ();
+#if GTK_CHECK_VERSION (3, 0, 0)
+		gdk_x11_set_sm_client_id (xsmp->client_id);
+#else
 		gdk_set_sm_client_id (xsmp->client_id);
+#endif
 		gdk_threads_leave ();
 
 		g_debug ("Got client ID \"%s\"", xsmp->client_id);
@@ -1188,6 +1195,7 @@ array_prop (const char *name, ...)
 		pv.value = value;
 		g_array_append_val (vals, pv);
 	}
+	va_end (ap);
 
 	prop->num_vals = vals->len;
 	prop->vals = (SmPropValue *)vals->data;
