@@ -143,7 +143,11 @@ terminal_screen_container_constructor (GType type,
 	g_assert (priv->screen != NULL);
 
 #ifdef USE_SCROLLED_WINDOW
+#if VTE_CHECK_VERSION (0, 38, 0)
+	priv->scrolled_window = gtk_scrolled_window_new (NULL, gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (priv->screen)));
+#else
 	priv->scrolled_window = gtk_scrolled_window_new (NULL, vte_terminal_get_adjustment (VTE_TERMINAL (priv->screen)));
+#endif
 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->scrolled_window),
 	                                priv->hscrollbar_policy,
@@ -163,7 +167,11 @@ terminal_screen_container_constructor (GType type,
 
 	priv->hbox = gtk_hbox_new (FALSE, 0);
 
+#if VTE_CHECK_VERSION (0, 38, 0)
+	priv->vscrollbar = gtk_vscrollbar_new (gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (priv->screen)));
+#else
 	priv->vscrollbar = gtk_vscrollbar_new (vte_terminal_get_adjustment (VTE_TERMINAL (priv->screen)));
+#endif
 
 	gtk_box_pack_start (GTK_BOX (priv->hbox), GTK_WIDGET (priv->screen), TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (priv->hbox), priv->vscrollbar, FALSE, FALSE, 0);
