@@ -32,17 +32,9 @@
 #include <gio/gio.h>
 
 #include <gdk/gdk.h>
-
-#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
-#ifndef GDK_IS_X11_DISPLAY
-#define GDK_IS_X11_DISPLAY(display) 1
-#endif
-#endif
 
-#ifdef WITH_SMCLIENT
 #include "eggsmclient.h"
-#endif
 
 #include "terminal-accels.h"
 #include "terminal-app.h"
@@ -442,7 +434,6 @@ name_lost_cb (GDBusConnection *connection,
  *
  */
 
-#ifdef GDK_WINDOWING_X11
 /* Copied from libcaja/caja-program-choosing.c; Needed in case
  * we have no DESKTOP_STARTUP_ID (with its accompanying timestamp).
  */
@@ -493,7 +484,6 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
 
 	return event.xproperty.time;
 }
-#endif
 
 static char *
 get_factory_name_for_display (const char *display_name)
@@ -527,17 +517,15 @@ get_initial_workspace (void)
   GdkAtom atom;
   GdkAtom cardinal_atom;
 
-  g_type_init ();
-
   window = gdk_get_default_root_window();
 
   atom = gdk_atom_intern_static_string ("_NET_CURRENT_DESKTOP");
   cardinal_atom = gdk_atom_intern_static_string ("CARDINAL");
 
-  gdk_property_get (window, atom, cardinal_atom, 0, 8, FALSE, NULL, NULL, NULL, &data);
-
-  ret = *(int *)data;
-  g_free (data);
+  if (gdk_property_get (window, atom, cardinal_atom, 0, 8, FALSE, NULL, NULL, NULL, &data)) {
+	  ret = *(int *)data;
+	  g_free (data);
+  }
   return ret;
 }
 
@@ -590,9 +578,7 @@ main (int argc, char **argv)
 	                                  &argc, &argv,
 	                                  &error,
 	                                  gtk_get_option_group (TRUE),
-#ifdef WITH_SMCLIENT
 	                                  egg_sm_client_get_option_group (),
-#endif
 	                                  NULL);
 
 	g_free (working_directory);
@@ -617,8 +603,7 @@ main (int argc, char **argv)
 	display_name = gdk_display_get_name (display);
 	options->display_name = g_strdup (display_name);
 
-#ifdef GDK_WINDOWING_X11
-	if (GDK_IS_X11_DISPLAY(display) && options->startup_id == NULL)
+	if (options->startup_id == NULL)
 	{
 		/* Create a fake one containing a timestamp that we can use */
 		Time timestamp;
@@ -627,7 +612,6 @@ main (int argc, char **argv)
 
 		options->startup_id = g_strdup_printf ("_TIME%lu", timestamp);
 	}
-#endif
 
 	if (options->use_factory)
 	{
